/******************************************************************************
*                                                                             *
* Copyright (c) 1990,							      *
* 	National Center for Atmospheric Research                              *
+                                                                             *
******************************************************************************/
    
#if !defined(lint) && !defined(VX)
static char rcsid[]=
"$Header: /net/src3/btcl/tclTCP2.1/src/RCS/readFullBuf.c,v 1.2 1994/08/04 13:27:31 vanandel Exp $";
#endif

/******************************************************************************
* Revision history:
* $Log: readFullBuf.c,v $
 * Revision 1.2  1994/08/04  13:27:31  vanandel
 * *** empty log message ***
 *
 * Revision 1.1  1994/03/09  18:46:39  vanandel
 * Initial revision
 *
 * Revision 1.2  90/02/12  14:29:18  vanandel
 * added RCS header
 * 
* 
*********************************END OF RCS INFO******************************/
#include <unistd.h>

/*
 * since we aren't guarenteed to get all the data requested when we
 * read a pipe, this utility function reads until it gets the 
 * amount requested
 */

int readFullBuf(fd, buf, size)
int fd;
char *buf;
int size;
{
    register int totalRead = 0;
    register int bytesLeft = size;
    register int cc;
    register char *p = buf;

    while (totalRead < size) 
    {
	cc = read(fd, p, bytesLeft);
	if ((cc == -1) || (cc == 0 ) )
	{
	    return(cc);
	}
	totalRead += cc;
	bytesLeft -= cc;
	p += cc;
    }
    return(totalRead);
}

